import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { CartCmsRepository } from "./cart-cms.repository";
import { UpdateCartCmsDto } from "./dto/update-cart-cms.dto";
import { CartCms } from "./entities/cart-cms.entity";

@Injectable()
export class CartCmsService {
    constructor(
        @InjectRepository(CartCmsRepository)
        private readonly repository: CartCmsRepository,
        private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
        dto: UpdateCartCmsDto,
        files: {
            topBannerImage: UploadedMulterFileI,
            bottomBannerImage: UploadedMulterFileI,
            bottomIconOne: UploadedMulterFileI,
            bottomIconTwo: UploadedMulterFileI
        }
    ): Promise<CartCms | Error> {
        if (files && files.topBannerImage) {
            const topBannerImage: any = await this.doSpaceService.uploadFile(files.topBannerImage[0], "CartCms/");
            dto.topBannerImage = topBannerImage;
        }
        if (files && files.bottomBannerImage) {
            const bottomBannerImage: any = await this.doSpaceService.uploadFile(files.bottomBannerImage[0], "CartCms/");
            dto.bottomBannerImage = bottomBannerImage;
        }
        if (files && files.bottomIconOne) {
            const bottomIconOne: any = await this.doSpaceService.uploadFile(files.bottomIconOne[0], "CartCms/");
            dto.bottomIconOne = bottomIconOne;
        }
        if (files && files.bottomIconTwo) {
            const bottomIconTwo: any = await this.doSpaceService.uploadFile(files.bottomIconTwo[0], "CartCms/");
            dto.bottomIconTwo = bottomIconTwo;
        }
        const isExists = await this.repository.find({ isDeleted: false });
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                    Constants.NOT_FOUND,
                    HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<CartCms[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}