import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { DealsPageCmsService } from "./deals-page-cms.service";
import { UpdateDealsPageCmsDto } from "./dto/update-deals-page-cms.dto";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";

@Controller({ path: "deals-page-cms", version: Constants.API_VERSION_1 })

export class DealsPageCmsController {
    constructor(private readonly service: DealsPageCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
      [
          { name: "bannerDesktopImage", maxCount: 1 },
          { name: "bannerMobileImage", maxCount: 1 }
      ]
    ))
    updateOrCreateData(
      @Body() dto: UpdateDealsPageCmsDto,
      @UploadedFiles() files: {
          bannerDesktopImage: UploadedMulterFileI,
          bannerMobileImage: UploadedMulterFileI
      }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
