import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    Query,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { HomePageCommonBannerCmsService } from "./home-page-common-banner-cms.service";
import { UpdateHomePageCommonBannerCmsDto } from "./dto/update-home-page-common-banner-cms.dto";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";

@Controller({ path: "home-page-common-banner-cms", version: Constants.API_VERSION_1 })

export class HomePageCommonBannerCmsController {
    constructor(private readonly service: HomePageCommonBannerCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
      [
          { name: "image", maxCount: 1 }
      ]
    ))
    updateOrCreateData(
      @Body() dto: UpdateHomePageCommonBannerCmsDto,
      @UploadedFiles() files: {
          image: UploadedMulterFileI,
      }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    // findAll(@Query("stateCode") stateCode: string) {
    findAll() {
        return this.service.findAll();
    }
}
