import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { LoginPageCmsDto } from "./dto/login-page-cms.dto";
import { LoginPageCms } from "./entities/login-page-cms.entity";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { LoginPageCmsRepository } from "./login-page-cms.repository";
import { InjectRepository } from "@nestjs/typeorm";

@Injectable()
export class LoginPageCmsService {
    constructor(
      @InjectRepository(LoginPageCmsRepository)
      private readonly repository: LoginPageCmsRepository
    ) {
    }

    async updateOrCreateData(dto: LoginPageCmsDto): Promise<LoginPageCms | Error> {

        const isExists = await this.repository.find({ isDeleted: false });
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                  Constants.NOT_FOUND,
                  HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                  Constants.UPDATE_FAILED,
                  HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<LoginPageCms[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(Constants.NOT_FOUND, HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}
