import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UploadedMulterFileI } from "../../SpacesModule/SpacesService";
import { DoSpacesService } from "../../SpacesModule/SpacesService/doSpacesService";
import { OfferPopupCmsRepository } from "./offer-popup-cms.repository";
import { UpdateOfferPopupCmsDto } from "./dto/update-offer-popup-cms.dto";
import { OfferPopupCmsEntity } from "./entities/offer-popup-cms.entity";

@Injectable()
export class OfferPopupCmsService {
    constructor(
        @InjectRepository(OfferPopupCmsRepository)
        private readonly repository: OfferPopupCmsRepository,
        private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
        dto: UpdateOfferPopupCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<OfferPopupCmsEntity | Error> {
        if (files && files.image) {
            const image: any = await this.doSpaceService.uploadFile(files.image[0], "OfferPopupCms/");
            dto.image = image;
        }
        // const isExists = await this.repository.find({ isDeleted: false });
        const isExists = await this.repository.find({
            stateCode: dto.stateCode,
            isDeleted: false
        });
        if (dto.isDefault) {
            // Retrieve all entities
            const entities = await this.repository.find();

            // Update the isDefault property for each entity
            for (const entity of entities) {
                const updateData = await this.repository.update(entity.id, { isDefault: false });
            }
            ;
        }
        // const isExists = await this.repository.find({ isDeleted: false });
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                    Constants.NOT_FOUND,
                    HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(stateCode: string): Promise<OfferPopupCmsEntity[] | Error> {
        const data = await this.repository.find({
            stateCode: stateCode,
            isDeleted: false
        });
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}