import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { ReserveTimeCmsService } from "./reserve-time-cms.service";
import { UpdateReserveTimeCmsDto } from "./dto/update-reserve-time-cms.dto";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";

@Controller({ path: "reserve-time-cms", version: Constants.API_VERSION_1 })

export class ReserveTimeCmsController {
    constructor(private readonly service: ReserveTimeCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
      [
          { name: "image", maxCount: 1 }
      ]
    ))
    updateOrCreateData(
      @Body() dto: UpdateReserveTimeCmsDto,
      @UploadedFiles() files: {
          image: UploadedMulterFileI
      }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
