import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { Constants } from "src/utils/constants";
import { DeliveryPagesService } from "./delivery-pages.service";
import { CreateDeliveryPagesDto } from "./dto/create-delivery-pages.dto";
import { UpdateDeliveryPagesDto } from "./dto/update-delivery-pages.dto";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "../../SpacesModule/SpacesService";

@Controller({ path: "delivery-pages", version: Constants.API_VERSION_1 })

export class DeliveryPagesController {
    constructor(private readonly service: DeliveryPagesService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([{ name: "bannerBackgroundImage", maxCount: 1 }]))
    create(@Body() dto: CreateDeliveryPagesDto,
        @UploadedFiles() files: { bannerBackgroundImage: UploadedMulterFileI }) {
        return this.service.create(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(":id")
    @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([{ name: "bannerBackgroundImage", maxCount: 1 }]))
    update(
        @Param("id") id: string,
        @Body() dto: UpdateDeliveryPagesDto,
        @UploadedFiles() files: {
            bannerBackgroundImage: UploadedMulterFileI,
        }) {
        return this.service.update(id, dto, files);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
