import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateBenefitsContentDto } from "./dto/create-benefits-content.dto";
import { UpdateBenefitsContentDto } from "./dto/update-benefits-content.dto";
import { BenefitsContentEntity } from "./entities/benefits-content.entity";

@EntityRepository(BenefitsContentEntity)
export class BenefitsContentRepository extends Repository<BenefitsContentEntity> {
    async createEntity(dto: CreateBenefitsContentDto): Promise<BenefitsContentEntity | Error> {
        try {
            const {
                buttonText,
                title,
                description,
                image
            } = dto;
            const entity = this.create({
                buttonText,
                title,
                description,
                image
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<BenefitsContentEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateBenefitsContentDto): Promise<BenefitsContentEntity | Error> {
        try {
            await this.update(id, {
                buttonText: dto.buttonText,
                title: dto.title,
                description: dto.description,
                image: dto.image
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<any | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(BenefitsContentEntity)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}