import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateBenefitsModalDto } from "./dto/create-benefits-modal.dto";
import { UpdateBenefitsModalDto } from "./dto/update-benefits-modal.dto";
import { BenefitsModalEntity } from "./entities/benefits-modal.entity";

@EntityRepository(BenefitsModalEntity)
export class BenefitsModalRepository extends Repository<BenefitsModalEntity> {
    async createEntity(dto: CreateBenefitsModalDto): Promise<BenefitsModalEntity | Error> {
        try {
            const {
                image,
                title,
                subTitle,
                termsAndConditionTitle
            } = dto;
            const entity = this.create({
                image,
                title,
                subTitle,
                termsAndConditionTitle
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<BenefitsModalEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateBenefitsModalDto): Promise<BenefitsModalEntity | Error> {
        try {
            await this.update(id, {
                image: dto.image,
                title: dto.title,
                subTitle: dto.subTitle,
                termsAndConditionTitle: dto.termsAndConditionTitle
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<BenefitsModalEntity[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(BenefitsModalEntity)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}