import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateBenefitsSectionLearnMoreDto } from "./dto/create-benefits-section-learn-more.dto";
import { UpdateBenefitsSectionLearnMoreDto } from "./dto/update-benefits-section-learn-more.dto";
import { BenefitsSectionLearnMoreEntity } from "./entities/benefits-section-learn-more.entity";

@EntityRepository(BenefitsSectionLearnMoreEntity)
export class BenefitsSectionLearnMoreRepository extends Repository<BenefitsSectionLearnMoreEntity> {
    async createEntity(dto: CreateBenefitsSectionLearnMoreDto): Promise<BenefitsSectionLearnMoreEntity | Error> {
        try {
            const {
                benefitsId,
                benefitsTitle,
                title,
                description,
                image
            } = dto;
            const entity = this.create({
                benefitsId,
                benefitsTitle,
                title,
                description,
                image
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<BenefitsSectionLearnMoreEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateBenefitsSectionLearnMoreDto): Promise<BenefitsSectionLearnMoreEntity | Error> {
        try {
            await this.update(id, {
                benefitsId: dto.benefitsId,
                benefitsTitle: dto.benefitsTitle,
                title: dto.title,
                description: dto.description,
                image: dto.image
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<BenefitsSectionLearnMoreEntity[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(BenefitsSectionLearnMoreEntity)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}