import { Body, Controller, Delete, Get, Param, Patch, Post, Query, UseGuards } from "@nestjs/common";
import { Constants } from "src/utils/constants";
import { CareerService } from "./career.service";
import { CreateCareerDto } from "./dto/create-career.dto";
import { UpdateCareerDto } from "./dto/update-career.dto";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";

@Controller({ path: "career", version: Constants.API_VERSION_1 })

export class CareerController {
    constructor(private readonly service: CareerService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    create(@Body() dto: CreateCareerDto) {
        return this.service.create(dto);
    }

    @Get()
    findAll() {
        return this.service.findAll();
    }

    @Get("/filter")
    // @UseGuards(AdminAuthGuard)
    filterData(
      @Query("sortBy") sortBy: string,
      @Query("city") city?: string,
      @Query("state") state?: string,
      @Query("jobType") jobType?: string,
      @Query("store") store?: string
    ) {
        return this.service.filterData(
          sortBy,
          city,
          state,
          jobType,
          store
        );
    }

    @Get(":id")
    // @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    @UseGuards(AdminAuthGuard)
    update(@Param("id") id: string, @Body() dto: UpdateCareerDto) {
        return this.service.update(id, dto);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
