import { EntityRepository, Repository } from "typeorm";
import { UpdateArticlePageUiDto } from "./dto/update-article-page-ui.dto";
import { ArticlePageUI } from "./entities/article-page-ui.entity";

@EntityRepository(ArticlePageUI)
export class ArticlePageUiRepository extends Repository<ArticlePageUI> {

    async createEntity(dto: UpdateArticlePageUiDto): Promise<ArticlePageUI | Error> {
        try {
            const entity = this.create({
                pageBackgroundColor: dto.pageBackgroundColor,
                titleFontColor: dto.titleFontColor,
                subTitleFontColor: dto.subTitleFontColor,
                buttonBackgroundColor: dto.buttonBackgroundColor,
                buttonFontColor: dto.buttonFontColor
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async updateEntity(dto: UpdateArticlePageUiDto, id: string): Promise<ArticlePageUI | Error> {
        try {
            await this.update(id, {
                pageBackgroundColor: dto.pageBackgroundColor,
                titleFontColor: dto.titleFontColor,
                subTitleFontColor: dto.subTitleFontColor,
                buttonBackgroundColor: dto.buttonBackgroundColor,
                buttonFontColor: dto.buttonFontColor
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findAll(): Promise<ArticlePageUI[] | Error> {
        try {
            return await this.find({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }
}