import { EntityRepository, Repository } from "typeorm";
import { UpdateCookiesSettingsPageUiDto } from "./dto/update-cookies-settings-page-ui.dto";
import { CookiesSettingsPageUI } from "./entities/cookies-settings-page-ui.entity";

@EntityRepository(CookiesSettingsPageUI)
export class CookiesSettingsPageUiRepository extends Repository<CookiesSettingsPageUI> {

    async createEntity(dto: UpdateCookiesSettingsPageUiDto): Promise<CookiesSettingsPageUI | Error> {
        try {
            const entity = this.create({
                titleFontColor: dto.titleFontColor,
                descriptionFontColor: dto.descriptionFontColor,
                pageBackgroundColor: dto.pageBackgroundColor,
                pageBreadcrumbFontColor: dto.pageBreadcrumbFontColor
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async updateEntity(dto: UpdateCookiesSettingsPageUiDto, id: string): Promise<CookiesSettingsPageUI | Error> {
        try {
            await this.update(id, {
                titleFontColor: dto.titleFontColor,
                descriptionFontColor: dto.descriptionFontColor,
                pageBackgroundColor: dto.pageBackgroundColor,
                pageBreadcrumbFontColor: dto.pageBreadcrumbFontColor
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findAll(): Promise<CookiesSettingsPageUI[] | Error> {
        try {
            return await this.find({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }
}