import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { StayEnlightenedUiRepository } from "./stay-enlightened-ui.repository";
import { UpdateStayEnlightenedUiDto } from "./dto/update-stay-enlightened-ui.dto";
import { StayEnlightenedUI } from "./entities/stay-enlightened-ui.entity";

@Injectable()
export class StayEnlightenedUiService {
    constructor(
      @InjectRepository(StayEnlightenedUiRepository)
      private readonly repository: StayEnlightenedUiRepository,
    ) {
    }

    async updateOrCreateData(
      dto: UpdateStayEnlightenedUiDto
    ): Promise<StayEnlightenedUI | Error> {
        const isExists = await this.repository.find({ isDeleted: false });
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                  Constants.NOT_FOUND,
                  HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                  Constants.UPDATE_FAILED,
                  HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<StayEnlightenedUI[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}