import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateHomePageSectionOneDto } from "./dto/create-home-page-section-one.dto";
import { UpdateHomePageSectionOneDto } from "./dto/update-home-page-section-one.dto";
import { HomePageSectionOne } from "./entities/home-page-section-one.entity";

@EntityRepository(HomePageSectionOne)
export class HomePageSectionOneRepository extends Repository<HomePageSectionOne> {
    async createEntity(dto: CreateHomePageSectionOneDto): Promise<HomePageSectionOne | Error> {
        try {
            const {
                titleOne,
                titleTwo,
                description,
                descriptionFontColor,
                buttonText,
                buttonLink,
                openNowButtonText,
                openNowButtonFile,
                showOpenNowButton,
                image,
                mobileImage,
                isDefault,
                titleOneColor,
                titleTwoColor,
                buttonBackgroundColor,
                buttonTextColor
            } = dto;
            const entity = this.create({
                titleOne,
                titleTwo,
                description,
                descriptionFontColor,
                buttonText,
                buttonLink,
                openNowButtonText,
                openNowButtonFile,
                showOpenNowButton,
                image,
                mobileImage,
                isDefault,
                titleOneColor,
                titleTwoColor,
                buttonBackgroundColor,
                buttonTextColor
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<HomePageSectionOne | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateHomePageSectionOneDto): Promise<HomePageSectionOne | Error> {
        try {
            await this.update(id, {
                titleOne: dto.titleOne,
                titleTwo: dto.titleTwo,
                description: dto.description,
                descriptionFontColor: dto.descriptionFontColor,
                buttonText: dto.buttonText,
                buttonLink: dto.buttonLink,
                openNowButtonText: dto.openNowButtonText,
                openNowButtonFile: dto.openNowButtonFile,
                showOpenNowButton: dto.showOpenNowButton,
                image: dto.image,
                mobileImage: dto.mobileImage,
                titleOneColor: dto.titleOneColor,
                titleTwoColor: dto.titleTwoColor,
                buttonBackgroundColor: dto.buttonBackgroundColor,
                buttonTextColor: dto.buttonTextColor
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<HomePageSectionOne[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async findByStateCode(stateCode: string): Promise<any | Error> {
        try {
            let data = await this.find({
                isDeleted: false
            })
            if (Object.keys(data).length === 0) {
                data = await this.find({
                    isDefault: true,
                    isDeleted: false
                });
                if (Object.keys(data).length === 0) {
                    data = await this.find({
                        isDeleted: false
                    });
                }
            }
            return data;
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(HomePageSectionOne)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}