import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import axios from 'axios';
import { iHeartJaneAuthentication } from 'src/helper/iheartjane-client-helper';
import { BenefitsSectionCmsRepository } from '../CMS/benefits-section-cms/benefits-section-cms.repository';
import { BenefitsContentRepository } from '../benefits-content/benefits-content.repository';
import { RetailerServiceIHeartJaneRepository } from '../iheartjane-services/custom-services/retailer-service/retailer-service-iheartjane.repository';
import { RetailerImageGalleryRepository } from '../retailer-image-gallery/retailer-image-gallery.repository';

@Injectable()
export class IheartjaneService {
    constructor(
        @InjectRepository(RetailerServiceIHeartJaneRepository)
        private readonly retailerServiceRepo: RetailerServiceIHeartJaneRepository,
        private readonly retailerImageGalleryRepo: RetailerImageGalleryRepository,
        private readonly benefitsSectionCmsRepo: BenefitsSectionCmsRepository,
        private readonly benefitsContentRepo: BenefitsContentRepository
    ) {
    }


    async authentication(): Promise<any | Error> {
        try {
            const data = await iHeartJaneAuthentication();
            return data;
        } catch (error) {
            console.log(error);
            return error;
        }
    }

    async allStore(): Promise<any | Error> {
        try {
            const authentication: any = await iHeartJaneAuthentication();
            if (authentication.access_token) {
                const apiUrl = `${process.env.IHEARTJANE_API_HOST}/api/roots/store_operations_api/v1/stores?page_size=50`;
                const config = {
                    headers: {
                        "Content-Type": "application/json",
                        "Authorization": `Bearer ${authentication.access_token}`
                    }
                };
                const response = await axios.get(apiUrl, config);
                if (response.status === 200) {
                    return response.data;
                }
            }
        } catch (error) {
            console.log(error);
            return error;
        }
    }

    async findOneStore(id: string): Promise<any | Error> {
        try {
            const authentication: any = await iHeartJaneAuthentication();
            if (authentication.access_token) {
                const apiUrl = `${process.env.IHEARTJANE_API_HOST}/api/roots/store_operations_api/v1/stores/${id}`;
                const config = {
                    headers: {
                        "Content-Type": "application/json",
                        "Authorization": `Bearer ${authentication.access_token}`
                    }
                };
                const response = await axios.get(apiUrl, config);
                if (response.status === 200) {
                    if (response?.data) {
                        const data = response?.data?.data?.store;
                        const retailerService = await this.retailerServiceRepo.findOne({
                            where: {
                                retailerId: data?.id,
                                isDeleted: false
                            }
                        });
                        if (retailerService) {
                            await this.retailerServiceRepo.update(retailerService.id, {
                                accessCount: retailerService.accessCount + 1
                            });
                        }
                        const retailerImage: any = await this.retailerImageGalleryRepo.find({
                            retailerId: data?.id,
                            isDeleted: false
                        });
                        data.retailerImages = retailerImage;
                        data.featuredImage = retailerService.featuredImage;
                        data.about = retailerService.about;
                        data.todaysSpecial = retailerService.todaysSpecial;
                        data.email = retailerService.email;
                        data.jarsRewards = retailerService.jarsRewards;
                        data.referAFriend = retailerService.referAFriend;
                        data.pageTitle = retailerService.pageTitle;
                        data.schema = retailerService.schema;
                        data.canonical = retailerService.canonical;

                        // benefits section 
                        const benefitsSectionCms = await this.benefitsSectionCmsRepo.findAll();
                        data.benefitsSectionCms = benefitsSectionCms;
                        const benefitsContent = await this.benefitsContentRepo.findByFilterQuery({});
                        data.benefitsContent = benefitsContent;
                        return data;
                    }
                }
            }
        } catch (error) {
            console.log(error);
            return error;
        }
    }

    async allSpecials(id: string): Promise<any | Error> {
        try {
            const authentication: any = await iHeartJaneAuthentication();
            if (authentication.access_token) {
                const apiUrl = `${process.env.IHEARTJANE_API_HOST}/api/roots/store_operations_api/v1/stores/${id}/specials?enabled=true&page_size=100
        `;
                const config = {
                    headers: {
                        "Content-Type": "application/json",
                        "Authorization": `Bearer ${authentication.access_token}`
                    }
                };
                const response = await axios.get(apiUrl, config);
                if (response.status === 200) {
                    return response.data;
                }
            }
        } catch (error) {
            console.log(error);
            return error;
        }
    }

    async allProducts(paginationId: number, pageSize: number): Promise<any | Error> {
        try {
            const authentication: any = await iHeartJaneAuthentication();
            if (authentication.access_token) {
                const apiUrl = `${process.env.IHEARTJANE_API_HOST}/api/roots/store_operations_api/v1/menu_products`;
                const config = {
                    headers: {
                        "Content-Type": "application/json",
                        "Authorization": `Bearer ${authentication.access_token}`
                    },
                    params: {
                        pagination_id: paginationId,
                        page_size: pageSize
                    }
                };
                const response = await axios.get(apiUrl, config);
                if (response.status === 200) {
                    return response.data;
                }
            }
        } catch (error) {
            console.log(error);
            return error;
        }
    }

    async findProductSlugOrProductId(slugOrProductId: string, storeIds: any): Promise<any | Error> {
        try {
            const authentication: any = await iHeartJaneAuthentication();
            if (authentication.access_token) {
                const apiUrl = `${process.env.IHEARTJANE_API_HOST}/api/roots/store_operations_api/v1/menu_products/menu_product_slug`;
                const config = {
                    headers: {
                        "Content-Type": "application/json",
                        "Authorization": `Bearer ${authentication.access_token}`
                    },
                    params: {
                        slug_or_product_id: slugOrProductId,
                        store_ids: storeIds
                    }
                };
                const response = await axios.get(apiUrl, config);
                if (response.status === 200) {
                    return response.data;
                }
            }
        } catch (error) {
            console.log(error);
            return error;
        }
    }
}
