import { EntityRepository, getConnection, Repository } from "typeorm";
import { UpdatePressReleaseCategoryDto } from "./dto/update-press-release-category.dto";
import { PressReleaseCategoryEntity } from "./entities/press-release-category.entity";
import { BasePressReleaseCategoryDto } from "./dto/base-press-release-category.dto";

@EntityRepository(PressReleaseCategoryEntity)
export class PressReleaseCategoryRepository extends Repository<PressReleaseCategoryEntity> {

    async createEntity(dto: BasePressReleaseCategoryDto): Promise<PressReleaseCategoryEntity | Error> {
        try {
            const entity = this.create({
                title: dto.title,
                imageOne: dto.imageOne,
                imageTwo: dto.imageTwo,
                isShowNav: dto.isShowNav
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async updateEntity(dto: UpdatePressReleaseCategoryDto, id: string): Promise<PressReleaseCategoryEntity | Error> {
        try {
            await this.update(id, {
                title: dto.title,
                imageOne: dto.imageOne,
                imageTwo: dto.imageTwo,
                isShowNav: dto.isShowNav
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findAll(): Promise<PressReleaseCategoryEntity[] | Error> {
        try {
            return await this.find({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<PressReleaseCategoryEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(PressReleaseCategoryEntity)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}